#
# spec file for package cgns
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libcgns4_4
Name:           cgns
Version:        4.4.0
Release:        2.7
Summary:        CFD General Notation System
License:        Zlib
Group:          Development/Libraries/Other
URL:            https://cgns.github.io/index.html
Source0:        https://github.com/CGNS/CGNS/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  cmake
BuildRequires:  f2c
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  hdf5-devel
BuildRequires:  libxml2-devel

%description
The CFD General Notation System (CGNS) provides a general, portable,
and extensible standard for the storage and retrieval of computational
fluid dynamics (CFD) analysis data.

%package -n %{libname}
Summary:        CFD General Notation System library
Group:          System/Libraries
Provides:       lib%{name} = %{version}
Obsoletes:      lib%{name} < %{version}
# Fix file conflict with incorrectly named shlib committed previously
Conflicts:      libcgns4_3

%description -n %{libname}
The CFD General Notation System (CGNS) provides a general, portable,
and extensible standard for the storage and retrieval of computational
fluid dynamics (CFD) analysis data.

%package devel
Summary:        CFD General Notation System library
Group:          Development/Libraries/Other
Requires:       %{libname} = %{version}
Provides:       lib%{name}-devel = %{version}
Obsoletes:      lib%{name}-devel < %{version}

%description devel
Files required to develop applications using CGNS (CFD General notation system).

%package devel-static
Summary:        CFD General Notation System library
Group:          Development/Libraries/Other
Requires:       %{name}-devel = %{version}

%description devel-static
Static CGNS (CFD General notation system) library.

%prep
%setup -q -n CGNS-%{version}

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"

%cmake \
%if %{__isa_bits} == 64
      -DCGNS_ENABLE_64BIT:BOOL=ON \
%endif
      -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
      -DCGNS_ENABLE_HDF5:BOOL=ON \
      -DCGNS_ENABLE_LEGACY:BOOL=ON \
      -DCGNS_ENABLE_FORTRAN:BOOL=ON \
      -DHDF5_NEED_ZLIB:BOOL=ON \

# Parallel build fails, see https://cgnsorg.atlassian.net/browse/CGNS-204
%cmake_build -j1

%install
%cmake_install

%if "%_lib" != "lib"
mv %{buildroot}%{_prefix}/lib %{buildroot}%{_libdir}
%endif

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%{_bindir}/*

%files -n %{libname}
%license license.txt
%doc release_docs/RELEASE.txt
%{_libdir}/libcgns.so.*

%files devel
%{_includedir}/*.h
%{_includedir}/cgns.mod
%{_includedir}/cgnsBuild.defs
%{_libdir}/libcgns.so
%{_libdir}/cmake/cgns

%files devel-static
%{_libdir}/libcgns.a

%changelog
* Thu Dec 28 2023 Dmitry Roshchin <dmitry_r@opensuse.org>
- Fix library package name
* Mon Dec 18 2023 Wang Jun <badboywj@gmail.com>
- Update to version 4.4.0
  * Removed possible overflow in cgi_error, #343 #701
  * Increased maximum open file limit default
  * Added control for HDF5 tuning routine
    "H5Pset_elink_file_cache_size," which is useful when many
    external links are used, #351
  * Fixed backward compatibility issues #702
  * Removed "NULL" and "UserDefined" Fortran parameters #349
  * More details: https://github.com/CGNS/CGNS/releases/tag/v4.4.0
* Tue May 17 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.3.0:
  * Add a context structure to handle cleanly cgio/hdf5 state
  * When opening a CGNS file with MLL the whole file is parsed.
  * Fix an uninitialized local array by copying m_dimvals to dimvals.
  * Set the default file_type in cg_open only when in write mode
  * Multiplication result converted to larger type fixes
- Update to version 4.2.0:
  * New C and Fortran APIs that allows for reading/writing datatypes
    that are different from cgsize_t
  * Added a diskless option for creating a CGNS file in memory and
    then to optionally persist the memory to disk.
  * Mapping of X4/X8 was lost when moving from ADF to HDF5.
    This fix reintroduces it as an experimental feature.
  * Tuned the parallel library algorithms to improve metadata type operations
  * Experimental support for conversion of FamilySpecified BC for
    AFLR3 file format, PR#247
  * Added check on node names according to SIDS
  * added warning if ZoneBC_t is missing while zone surfaces are
    present in a 3D mesh.
* Thu Nov 12 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.1.2:
  * Fixed the Compatibility issue between v3.4.0 and v4.1.1 (CGNS-214).
  * Change a wrong check in cg_poly_element_read to load older CGNS
    file section with CGNS 4.x API (CGNS-219).
* Tue Apr  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix last change (typo in spec file, should be %%_lib not %%lib).
* Tue Apr  7 2020 Andreas Schwab <schwab@suse.de>
- Handle all architectures with %%_lib != lib
* Fri Apr  3 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.1.1:
  * (CGNS-196) Fixed the compilation of cgnstools, which still
    made use the Removed APIs in 4.1.0
- Update to version 4.1.0:
  * Added CPEX42 Storing bounding box of a grid (CGNS-149).
  * Added CPEX43 Family hierarchy as a tree (CGNS-180).
- Update to version 4.1.0:
  * Added CPEX 41 NGON modification proposal (CGNS-121).
- The removal of CPEX 41 NGON in 3.4.1 broke gmsh and Paraview
* Sun Mar 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.4.1:
  * Restore backward compatibility by removing CPEX 41 NGON
    modification made in version 3.4.0.
- Update shlib package name to respect upstream's so version.
- Pass CMAKE_SKIP_INSTALL_RPATH=ON to cmake to disable setting
  rpath on installed libs; prevents build failures on Leap 15.2.
- Use %%{name}-%%{version} naming scheme for source tarball.
- Use %%cmake_build instead of invoking make directly.
- Minor cleanups using spec-cleaner.
* Fri Aug  2 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Split static library into separate package.
- Use FAT LTO objects in order to provide proper static library.
* Sat Jul 27 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 3.4.0
  For a list of changes between 3.3.1 and 3.4.0, see included Release.txt
- Set License tag SPDX "Zlib", attribution is appreciated but not required
- Spec file cleanup
* Tue Jul 14 2015 toddrme2178@gmail.com
- Fix building on ppc64le and aarch64
* Thu Jul 17 2014 kilian@lackhove.de
- fixed 64-bit core, HDF5, Legacy and fortran build flags.
* Fri Mar 14 2014 toddrme2178@gmail.com
- Update to 3.2.1
  - fixed problem with IS_FIXED_SIZE macro for cubic elements
  - added check for open file to routines that don't take
    a file number (suggestion from Marc Poinet)
  - added HTMLHelp interface to cmake scripts
  - added AdditionalFamilyName to UserDefinedData
  - fixed compiler complaint about comparison between int and enum
  - added routines to set MPI communicator for parallel I/O
  - updated CMake scripts to work within other scripts (remove conflicts)
  - updates to some cgnstools utility conversion routines
  - fixes and updates to tests and cgnscheck
  - updates to support CG_FILE_ADF2 (2.5 compatibility)
  - fix for point set subregions
- Update to  3.2
  - full integration of parallel I/O using HDF5 with MPI
  - implemented CPEX 0033 and 0034
  - compression (rewriting) of file to remove unused space is no
    longer automatically done, since may interfere with parallel I/O.
    Added cgnscompress program to tools to do this afterwards.
  - removed cgnsversion program from tools since support was getting
    out of hand (N squared problem with versions).
  - added routines to convert to and from AFLR3, FAST, and TetGen
  - implemented cubic elements (CPEX 0036)
  - CGNStools documentation no longer included with source.
    The NASA Glenn website (or local copy) is now used instead.
- Update to 3.1.4-2
  - fixes to cmake scripts for Fortran
  - added check for open file to routines that don't take
    a file number (suggestion from Marc Poinet)
  - CGNStools documentation no longer included with source.
    The NASA Glenn website (or local copy) is now used instead.
  - save window size for cgnsview
  - fix to computing path lists in CMake script
- Update to 3.1.4
  - added some const definitions to library
  - moved unlink of filename when using CG_MODE_WRITE on open to cgio
  - fixed goto for FamilyBCDataset for UserData, .etc
  - added cg_get_cgio_f and cg_root_id_f Fortran routines
  - fixed cmake and configure scripts to allow MPI with HDF5 and
    fixed bugs in those scripts
  - updated CGNSplot to handle all element types and 1-d and 2-d cases
  - fixes to cgnscheck
  - cleaned up some compiler warnings
  - added cgnsBuild.defs Makefile include to installation
  - removed unneeded tools directory from cgnstools
  - cgnstools no longer built automatically - need to set configure flag
  - allow CellCenter for BCs
  - added cg_precision and cg_precision_f functions to get integer
    size used to create the file (32 or 64)
* Sun Oct 14 2012 scorot@free.fr
- enable legacy and fortran interface
* Sat Oct 13 2012 scorot@free.fr
- spec file reformating
- install shared librarie and put it in a separate package
- enable hdf5 support
- update to version 3.1.3
  * No changelog available
